==> hydrogen_1.0.0~rc1.orig.tar.gz: hydrogen-1.0.0-rc1/src/gui/src/SampleEditor/DetailWaveDisplay.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2008 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 *
 * http://www.hydrogen-music.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef DETAIL_WAVE_DISPLAY
#define DETAIL_WAVE_DISPLAY

#include <QtGui>
#if QT_VERSION >= 0x050000
#  include <QtWidgets>
#endif
#include <hydrogen/object.h>

namespace H2Core
{
	class Sample;
}

class DetailWaveDisplay : public QWidget, public H2Core::Object
{
    H2_OBJECT
	Q_OBJECT

	public:
		DetailWaveDisplay(QWidget* pParent);
		~DetailWaveDisplay();

		void updateDisplay( QString filename );

		void paintEvent(QPaintEvent *ev);
		void setDetailSamplePosition( unsigned posi, float zoomfactor, QString type);

	private:
		QPixmap m_background;
		QString m_sSampleName;
		int *m_pPeakDatal;
		int *m_pPeakDatar;
		int m_pDetailSamplePosition;
		int m_pNormalImageDetailFrames;
		float m_pZoomFactor;
		QString m_pType;
};


#endif

==> hydrogen-1.2.3.tar.gz: hydrogen-1.2.3/src/gui/src/SampleEditor/DetailWaveDisplay.h <==
/*
 * Hydrogen
 * Copyright(c) 2002-2008 by Alex >Comix< Cominu [comix@users.sourceforge.net]
 * Copyright(c) 2008-2024 The hydrogen development team [hydrogen-devel@lists.sourceforge.net]
 *
 * http://www.hydrogen-music.org
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY, without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see https://www.gnu.org/licenses
 *
 */

#ifndef DETAIL_WAVE_DISPLAY
#define DETAIL_WAVE_DISPLAY

#include <QtGui>
#include <QtWidgets>

#include <core/Object.h>

namespace H2Core
{
	class Sample;
}

/** \ingroup docGUI*/
class DetailWaveDisplay :  public QWidget,  public H2Core::Object<DetailWaveDisplay>
{
    H2_OBJECT(DetailWaveDisplay)
	Q_OBJECT

	public:
		explicit DetailWaveDisplay(QWidget* pParent);
		~DetailWaveDisplay();

		void updateDisplay( QString filename );

		virtual void paintEvent(QPaintEvent *ev) override;
		void setDetailSamplePosition( unsigned posi, float zoomfactor, QString type);

	private:
		QPixmap m_background;
		QString m_sSampleName;
		int *m_pPeakDatal;
		int *m_pPeakDatar;
		int m_pDetailSamplePosition;
		int m_pNormalImageDetailFrames;
		float m_pZoomFactor;
		QString m_pType;
};


#endif
